<template>
  <!-- 产品信息弹窗 -->
  <div>
    <el-dialog title="修改基础信息" :visible="visible" :before-close="handleClose" custom-class="bbsl-location-dialog"
               width="80%">
      <div>
        <el-form ref="formInfo" :rules="rules" :model="parameter" label-width="150px">
          <el-collapse accordion v-model="activeCollapse1" class="form-collapse">
            <el-collapse-item name="1">
              <template slot="title">
								<span class="collapse-title">
									<i class="collapse-title-icon el-icon-info"></i>
									产品基础信息
								</span>
              </template>
              <el-row>
                <el-col :span="12">
                  <el-form-item label="产品编码：" prop="code">
                    <el-input clearable placeholder="请输入产品编码" v-model="parameter.code" disabled></el-input>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item label="产品名称：" prop="name">
                    <el-input clearable placeholder="请输入产品名称" v-model="parameter.name"></el-input>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="12">
                  <el-form-item label="设备类型：" prop="deviceType">
                    <el-select style="width:100%" placeholder="请选择设备类型" clearable
                               v-model="parameter.deviceType">
                      <el-option v-for="item in deviceTypeList" :key="item.value"
                                 :label="item.name" :value="item.value"></el-option>
                    </el-select>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item label="智能分类：" prop="isIntellect">
                    <el-select style="width:100%" placeholder="请选择智能分类" clearable
                               v-model="parameter.isIntellect">
                      <el-option v-for="item in isIntellectList" :key="item.value"
                                 :label="item.name" :value="item.value"></el-option>
                    </el-select>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item inline="true" label="所属分类：" prop="typeId">
                    <el-cascader clearable ref="cascader" v-if="typeOptions"
                                 v-model="parameter.typeId" placeholder="请选择所属分类" :options="typeOptions"
                                 filterable :props="{value: 'id', label: 'name', checkStrictly: true}"
                                 @change="handleChange('fullName')" style="width: 100%"></el-cascader>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="24">
                  <el-form-item label="图标：" prop="icon">
                    <svgIcon
                      icon-style="icon"
                      :icon-class="parameter.icon"
                      v-if="parameter.icon"
                      style="font-size: 24px; vertical-align: middle;margin-right: 10px; "
                    />
                    <el-button
                      class="choseIcons"
                      size="small"
                      @click="$refs.iconPanl.dialogVisible = true"
                      style="margin-right: 10px; vertical-align: middle"
                      title="选择图标"
                    >
                      <!--              <i class="el-icon-picture-outline" v-show="!meunIcon"/>-->
                      <span> 选择图标</span>
                    </el-button>
                    <el-button
                      class="choseIcons"
                      size="small"
                      @click="clearIcon"
                      style="vertical-align: middle"
                      title="选择图标"
                    >
                      <!--              <i class="el-icon-picture-outline" v-show="!meunIcon"/>-->
                      <span>取消图标</span>
                    </el-button>
                    <!-- <el-upload name="files" class="avatar-uploader" :action="uploadUrl"
                      :show-file-list="false" :headers="header"
                      accept="image/jpg,image/jpeg,image/png" :data="{flowKey: '', params: ''}"
                      :on-success="handleAvatarSuccess" :before-upload="beforeAvatarUpload">
                      <img v-if="parameter.icon" :src="this.icon" class="avatar" />
                      <i v-else class="el-icon-plus avatar-uploader-icon"></i>
                    </el-upload> -->

                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="24">
                  <el-form-item label="备注：" prop="memo">
                    <el-input type="textarea" :autosize="{minRows: 4}" placeholder="请输入备注内容"
                              v-model="parameter.memo">
                    </el-input>
                  </el-form-item>
                </el-col>
              </el-row>
            </el-collapse-item>
          </el-collapse>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
				<el-button type="primary" @click="handleSave">保存</el-button>
				<el-button @click="handleClose">取 消</el-button>
			</span>
    </el-dialog>
    <IconPanl @select="choseIcon" ref="iconPanl" />
  </div>
</template>

<script>
import productManage from '@/api/device/productManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import IconDialog from '@/components/dialog/IconDialog.vue'
import IconPanl from '@/components/selector/IconPanl.vue'
import {
  mapState
} from 'vuex'
import utils from '@/hotent-ui-util.js'

export default {
  props: {
    parameter: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  name: 'BasicInformationDialog',
  components: {
    IconDialog,
    IconPanl
  },
  data() {
    return {
      visible: false,
      title: '新增',
      activeCollapse1: '1',
      ctlTypeList: '',
      active: 1,
      previewUrl: window.context.portal + '/file/onlinePreviewController/v1/getFileById_',
      uploadUrl: window.context.portal + '/file/v1/fileUpload',
      icon: '',
      deviceTypeList: [], //设备类型字段列表
      isIntellectList: [], //智能分类字段列表
      typeOptions: [], //产品分类数据
      rules: {
        name: [{
          required: true,
          message: '请输入产品名称',
          trigger: 'blur'
        }],
        isIntellect: [{
          required: true,
          message: '请选择智能分类',
          trigger: 'blur'
        }],
        code: [{
          required: true,
          message: '请输入产品编码',
          trigger: 'blur'
        }],
        deviceType: [{
          required: true,
          message: '请选择设备类型',
          trigger: 'blur'
        }]
      }
    }
  },
  created() {
    this.deviceTypeList = dictUtils.getDictItemsFromCache('sblx')
    this.ctlTypeList = dictUtils.getDictItemsFromCache('kjlx')
    this.isIntellectList = dictUtils.getDictItemsFromCache('znfl')
    this.icon = this.previewUrl + this.parameter.icon

  },
  mounted() {
    this.treeType()
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  methods: {
    clearIcon() {
      this.parameter.icon = ''
    },
    choseIcon(icon) {
      this.parameter.icon = icon
    },
    handleAvatarSuccess(res, file) {
      console.log(res.fileId)
      console.log(this.previewUrl + res.fileId)
      this.$set(this.parameter, 'icon', res.fileId)
      this.icon = this.previewUrl + res.fileId
    },
    beforeAvatarUpload(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt1M = file.size / 1024 / 1024 < 1
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      if (!isLt1M) {
        this.$message.error('上传图片大小不能超过 1MB!')
      }
      return isJPG && isLt1M
    },
    add() {
      this.visible = true
      console.log(this.parameter, 'ppppppppp')
      this.icon = this.previewUrl + this.parameter.icon
    },
    treeType() {
      productManage.productType().then(res => {
        this.typeOptions = res.value
      })
    },
    handleChange(type) {
      if (type == 'fullName') {
        let nodes = this.$refs.cascader.getCheckedNodes()
        console.log(nodes)
        if (nodes && nodes.length > 0) {
          this.parameter.typeId = nodes[0].data.id
          this.parameter.fullId = nodes[0].data.fullId
          this.parameter.fullName = nodes[0].data.fullName
        } else {
          this.$refs.cascader.$refs.panel.clearCheckedNodes()
          this.$refs.cascader.$refs.panel.checkedValue = '' // 清空选中值
          this.$refs.cascader.$refs.panel.activePath = '' // 清除高亮
          this.$refs.cascader.$refs.panel.syncActivePath() // 初始化（只展示一级节点）
          this.parameter.fullName = ''
          this.parameter.fullId = ''
        }
      }
    },
    handleSuccess(res, file) {
      const portal = window.context.portal
      let uploadUrl = portal + '/file/v1/uploadFileForConfig'
      console.log(res, 'llllll', file)
      console.log(uploadUrl)
      this.$set(this.parameter, 'icon', res.fileId)
      this.icon = this.previewUrl + res.fileId
    },
    beforeUpload(file) {
      const isJPG = file.type === 'image/jpeg'
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      return isJPG
    },
    // 保存产品信息
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          productManage.updateProductInfo(this.parameter).then(response => {
            console.log(this.parameter, '修改')
            if (response.state) {
              this.$notify({
                type: 'success',
                message: '修改成功',
                duration: 2000
              })
              this.handleClose()
              this.$parent.loadData(1)
            } else {
            }
          })
        } else {
          return false
        }
      })
    },
    // 关闭新增人员窗口
    handleClose() {
      this.visible = false
      this.activeCollapse1 = '1'
    }
  }
}
</script>

<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}

.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}

.column-box {
  color: #409eff;
  display: flex;
  justify-content: space-evenly;
}

.avatar {
  width: 24px;
  height: 24px;
}
</style>
